/* image thumbnails */

.blogImageContainer {
    float:left;
    margin:1em 0;
    width:140px;
}

.blogImageContainer #parent-fieldname-image img,
.blogEntryTitleImage img {
    border:1px solid #666;
    -webkit-border-radius:2px;
    -moz-border-radius:2px;
    border-radius:2px;
    box-shadow:1px 1px 4px #888a85;
}

.blogEntryTitleImage {
    float:right;
    margin:0.5em 0;
    text-align:center;
    width:410px;
    padding-left:10px;
}

.blogEntryAuthorPortrait {
    float:left;
    margin:-12px 0 0 0;
}

.blogEntryAuthorPortrait img {
    width:48px !important;
    height:auto !important;
}

/* @end */

/* image overlays (popups) */

div.overlay {
    width: auto;
    height: auto;
    /* initially overlay is hidden */
    display: none;
    /* some padding to layout nested elements nicely  */
    margin: 1em;
    font-size: 80%;
    z-index:1000;
}

/* default close button positioned on upper right corner */
    div.overlay div.close {
    background-image: url(++resource++collective.blogging.static/close.png);
    position: absolute;
    right: -14px;
    top: -14px;
    cursor: pointer;
    height: 30px;
    width: 30px;
}

.pb-image {
    white-space: normal;
    box-shadow: 0 0 3em 0.5em #666;
    -moz-box-shadow: 0 0 3em 0.5em #666;
    -webkit-box-shadow: 0 0 3em #666;
}


div.overlay div.close span {
    display: block;
    height: 1px;
    margin: -1px 0 0 -1px;
    overflow: hidden;
    padding: 0;
    width: 1px;
}

/* @end */


/* gallery styling for the image wrapper  */

#gallery-box div.imageTitle {
    background:#fff;
    border:1px solid #8CACBB;
    border-top:0 none;
    width:380px;
    margin:0 auto 5px auto;
    padding:5px 10px;
}

#gallery-box div.imageTitle a {
    color:#76797C;
    text-decoration:none;
}

#gallery-box div.imageTitle a:hover {
    color:#000;
}

#image_wrap {
    /* dimensions */
    width:100%;
    margin:15px 0 0 0;
    padding:15px 0;

    /* centered */
    text-align:center;

    /* some "skinning" */
    background-color:#DEE7EC;
    border:2px solid #fff;
    outline:1px solid #8CACBB;
    -moz-ouline-radius:4px;
}

#image_wrap img {
    border:1px solid #8CACBB;
}

/* you may want to setup some decorations to active the item */
div.galleryItems img {
    border:2px solid #fff;
    outline:1px solid #8CACBB;
}

div.galleryItems img.active {
    border:2px solid #FFA500;
    background-color:#fff;
}

/* scrollable buttons */
#gallery-box a.browse {
-moz-background-clip:border;
-moz-background-inline-policy:continuous;
-moz-background-origin:padding;
background:transparent url(++resource++collective.blogging.static/hori_large.png) no-repeat scroll 0 0;
cursor:pointer;
display:block;
float:left;
font-size:1px;
height:30px;
margin:5px 10px;
width:30px;
}

#gallery-box a.right {
background-position:0 -30px;
clear:right;
float:right;
margin-right:0;
}

#gallery-box a.right:hover {
background-position:-30px -30px;
}

#gallery-box a.right:active {
background-position:-60px -30px;
}

#gallery-box a.left {
margin-left:0;
}

#gallery-box a.left:hover {
background-position:-30px 0;
}

#gallery-box a.left:active {
background-position:-60px 0;
}

#gallery-box a.disabled {
visibility:hidden !important;
}

/* events / maps */
td.entryMap div.googleMapLocation {
    width:100%;
}

/* various styles */
.helpTopLink {
    float:right;
}

.blogArchivePortlet div.archiveMonth {
    padding-left:1em;
}

.blogArchivePortlet span.archiveCount {
    font-weight:bold;
}

.blogArchivePortlet div.archiveMonths {
    padding-left: 1em;
}

dl.sharePortlet a {
    border-bottom:0 none!important;
}

div.manageBlogLinks {
    padding-top:0.5em;
}

#filter-blog-form label {
    font-weight: normal;
}

#filter-blog-form td {
    padding: 0 1em 1em 0;
}

#filter-blog-form select {
    width: 100%;
}

.blogPostsCount {
    padding-top:0;
}

div.tileFooter {
    border:1px solid #8CACBB;
    background-color:#DEE7EC;
    padding:0.4em 1em;
}

div.entrySharing {
    float:right;
}

div.entrySharing a {
    border-bottom:0 none!important;
}

/* Shared CSS between the two tab types */
#content div.tileFooter {
    background:#DDDDDD;
    border:0.3em solid #DDDDDD;
    display: block;
    margin-left: 0;
    margin-bottom:2.5em;
    border-top-right-radius: 0.5em;
    border-top-left-radius: 0.5em;
    -webkit-border-top-right-radius: 0.5em;
    -webkit-border-top-left-radius: 0.5em;
    -webkit-border-bottom-right-radius: 0.5em;
    -webkit-border-bottom-left-radius: 0.5em;
    -moz-border-radius-topleft: 0.5em;
    -moz-border-radius-topright: 0.5em;
    -moz-border-radius-bottomleft: 0.5em;
    -moz-border-radius-bottomright: 0.5em;
}

dl#blog-filter {
    border:0.1em solid #DDDDDD;
    margin:1em 0 1em 0;
    padding:0;
    border-top-right-radius: 0.5em;
    border-top-left-radius: 0.5em;
    -webkit-border-top-right-radius: 0.5em;
    -webkit-border-top-left-radius: 0.5em;
    -webkit-border-bottom-right-radius: 0.5em;
    -webkit-border-bottom-left-radius: 0.5em;
    -moz-border-radius-topleft: 0.5em;
    -moz-border-radius-topright: 0.5em;
    -moz-border-radius-bottomleft: 0.5em;
    -moz-border-radius-bottomright: 0.5em;
}

dl#blog-filter dt.collapsibleHeader {
    background:#205C90;
    border:0 none;
    color:white;
    font-weight:normal;
    padding:0.4em 1em 0.4em 1em;
    border-top-right-radius: 0.5em;
    border-top-left-radius: 0.5em;
    -webkit-border-top-right-radius: 0.5em;
    -webkit-border-top-left-radius: 0.5em;
    -webkit-border-bottom-right-radius: 0.5em;
    -webkit-border-bottom-left-radius: 0.5em;
    -moz-border-radius-topleft: 0.5em;
    -moz-border-radius-topright: 0.5em;
    -moz-border-radius-bottomleft: 0.5em;
    -moz-border-radius-bottomright: 0.5em;
}

dl#blog-filter dd.collapsibleContent {
    padding:0 1em;
}

span#plone-document-byline {
    color:#666666;
    display:block;
    font-size:85%;
    margin-top:0;
}

span#plone-document-byline a,
span#plone-document-byline a:visited {
    color: #205C90!important;
}

div.blogListingEntry h2 a {
    border-bottom:0 none!important;
}

.template-blog_entry_view #content h1.documentFirstHeading,
.template-blog_entry_view #content .documentByLine {
    margin-left:75px;
}
