"""Common configuration constants
"""

PROJECTNAME = 'xhostplus.blog'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'BlogEntry': 'xhostplus.blog: Add Blog Entry',
    'Blog': 'xhostplus.blog: Add Blog',
}
